@@ -1,3 +1,3 @@
-from .interactive import clear, pr, ask, banner, choose, pause, cyan, generic_menu_loop, get_date
+from .interactive import clear, pr, ask, banner, choose, pause, cyan, get_date
 from .net import get_net, is_mac, ping
 from .fs import choose_file, count_lines, file_volume, human_bytes, is_image, is_package
